==> tts_cepstral_V2.0_2010-03-15_13.tar.gz: tts_cepstral_V2.0_2010-03-15_13/www/config.php <==
<?
#Active CDR statistics :
$enable_record_to_cdr=false;


#Common Languages en variantes
#http://www.w3.org/International/articles/language-tags/
#
# language-Script-REGION-variant-extension-privateuse
#
#The entries in the registry follow certain conventions with regard to upper and 
#lowercasing - for example, language tags are lower case, alphabetic region subtags
#are upper case, and script tags begin with an initial capital. This is only a 
#convention! When you use these subtags you are free to do as you like.



#default tts engine is the first in this tts array :
$tts=array();





#cepstral_begin
$tts["cepstral"]= array(
      "name" => "cepstral",
      "program"  => "/opt/swift/bin/swift",
      "args" => array('-n $speaker -m text','-f $filename', '-o $filename.$iformat'),
      "gender" => array( 
                        'male'    => array('David'),
                        'female'  => array(),
                       ),
      "langcodes" => array(
                          'en-US' => array('code'=>'en_us', 'speakers'=> array('David')),
                        ),
      "charsets" => array('UTF-8'),
      "codecs" => array('pcm'=>'pcm'),
      "iformats" => array('wav'),
      "vxiformats" => array(
                           'wav'  => array('iformat'=>'wav','codec'=>'pcm'),
                          ),
      "formatiscodec"=>false,
      "debugargs"=>"-t --events",
);
#cepstral_end



# vim: set filetype=php expandtab tabstop=2 shiftwidth=2 autoindent smartindent:

==> tts_cepstral_V3.0_2010-05-25_23.tar.gz: tts_cepstral_V3.0_2010-05-25_23/www/config.php <==
<?
#Active CDR statistics :
$enable_record_to_cdr=false;


#Common Languages en variantes
#http://www.w3.org/International/articles/language-tags/
#
# language-Script-REGION-variant-extension-privateuse
#
#The entries in the registry follow certain conventions with regard to upper and 
#lowercasing - for example, language tags are lower case, alphabetic region subtags
#are upper case, and script tags begin with an initial capital. This is only a 
#convention! When you use these subtags you are free to do as you like.


#default tts engine is the first in this tts array :
$tts=array();
#cepstral_begin
$tts["cepstral"]= array(
      "name" => "cepstral",
      "call"  => "/opt/swift/bin/swift",
      "options" => array('-n $voice -m text','-f $filename', '-o $filename.$iformat'),
      "voices"=>array(
                      'David'  => array(
                                          'type'=>'male',
                                          'desc'=>'English Male from Unit States',
                                          'voptions' => array ()
                                       ),
      ),
      "langcodes" => array(
                          'en' => array('David'),
                          'en-US' => array('David'),
                        ),
      "charsets" => array('UTF-8'),
      "codecs" => array('pcm'=>'pcm'),
      "iformats" => array('wav'),
      "vxiformats" => array(
                           'wav'  => array('iformat'=>'wav','codec'=>'pcm'),
                          ),
      "formatiscodec"=>false,
      "debugargs"=>"-t --events",
      "checks"=>array("/opt/swift/bin/swift"),
);
#cepstral_end





# vim: set filetype=php expandtab tabstop=2 shiftwidth=2 autoindent smartindent:
